{ metabolic mass product in people, bioyield mass in people, bioproduct mass in people, typical sapien bioproduct mass, sapien-metabolic mass, possible mass after bioactivity in people, probable mass after bioactivity in people, potential mass after bioactivity in people, potential eventual mass after bioactivity in people, potential future mass (after bioactivity in people), mass equivalents, likely eventual mass, likely mass yield, likely generated mass, effectual mass, effectuals, probable eventualities, eventualities, consequentials, resultants, futures, destinies } description: The mass after bioactivity in people. similar: https://en.wikipedia.org/wiki/Biological_activity metabolic https://en.wikipedia.org/wiki/International_unit https://en.wikipedia.org/wiki/Efficacy